clear all; format compact; clc;
disp('Adjusting Sacrum Curvature');

%% initial inputs
BaseModel = 'Test.osim';
Sacrum_Inclination = 35; %degrees, do something severe so you can see it
    Sacrum_Inclination = Sacrum_Inclination * pi/180; %put in radians
NewModel = 'Test_Adjust'; %new adjusted model name   

%% Load the baseline model and initialize and model info
    import org.opensim.modeling.* %This opens the OpenSim modeling classes

    model = Model(BaseModel);
        myJoints = model.getJointSet();
        Rbodies = model.get_BodySet(); % Rbodies.getSize()

%% Rotate Sacrum
    % joint to adjust
    JointName = 'pelvis_sacrum'; %seperate with ;
    % joint to adjust
    BodyName = {'lumbar5'}; %good reference body frame for Sacrum because it's axis attached to top of Sacrum
    
    % get initial Sacrum (lumbar 5) linear position in GCS    
    state = model.initSystem();

    Sacrum_Pos = Rbodies.get(BodyName) ;   
        Sacrum_Pos_gPos = Sacrum_Pos.getPositionInGround(state);
        Sacrum_Posr_gPos_PRE = osimVec3ToArray(Sacrum_Pos_gPos); %initial position prior to rotation

    % rotate sacrum the desired amount
    NewOriR = ArrayDouble.createVec3([0,0, Sacrum_Inclination]); %in radians 
        myJoints.get(JointName).get_frames(1).set_orientation(NewOriR); 

%% move back in initial linear position        
    % get new linear position of Sacrum    
    state = model.initSystem();  %get new rotated state

    Sacrum_Pos = Rbodies.get(BodyName) ;   
        Sacrum_Pos_gPos = Sacrum_Pos.getPositionInGround(state);
        Sacrum_Posr_gPos_POST = osimVec3ToArray(Sacrum_Pos_gPos);  %new rotated position

    % Calculate how much Lumbar5 moved
    Moved = Sacrum_Posr_gPos_POST - Sacrum_Posr_gPos_PRE; %how much you move the Sacrum back so it is in the same position as before

    % Adjust Sacrum back to position based on L5 movement
    NewPosR = ArrayDouble.createVec3(-Moved); %how much you move the Sacrum back so it is in the same position as before
        myJoints.get(JointName).get_frames(0).set_translation(NewPosR);

%% save new adjusted model
 model.setName(NewModel);
    New_modelpath = [char(model.getName()) '.osim']; 
model.print(New_modelpath);  %%% stop here and run like I used too!
